@@ -4,6 +4,7 @@ import logging
 from ming.utils import LazyProperty
 from ming.orm.ormsession import ThreadLocalORMSession
 from pylons import tmpl_context as c
+from timermiddleware import Timer
 
 # Pyforge-specific imports
 import allura.tasks
@@ -89,3 +90,16 @@ class ForgeHgApp(RepositoryApp):
         else:
             allura.tasks.repo_tasks.init.post()
 
+
+def hg_timers():
+    import mercurial.hg
+    return [
+        Timer('hg_lib.{method_name}', mercurial.hg.localrepo.localrepository, 'heads',
+              'branchtags', 'tags'),
+        Timer('hg_lib.{method_name}', mercurial.cmdutil, 'walkchangerevs'),
+    ]
+
+
+def forgehg_timers():
+    return Timer('hg_tool.{method_name}', HM.hg.HgImplementation, '*')
+
